aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/dist
diff options
context:
space:
mode:
authorRuss Cox <rsc@golang.org>2022-10-05 21:13:08 -0400
committerRuss Cox <rsc@golang.org>2022-10-17 19:46:59 +0000
commit07c57aff5d6d8f1df96eb99507bd04c57d0616ca (patch)
tree5c40fb691db99e17741f7ad85a86773b542f01bb /src/cmd/dist
parentb65e259e56a326295250f037efbd31f64bcdfbfe (diff)
downloadgo-07c57aff5d6d8f1df96eb99507bd04c57d0616ca.tar.xz
all: use Go 1.17.13 for bootstrap
Previously we used Go 1.17, but we realized thanks to tickling a pre-Go1.17.3 bug that if we are going to change the bootstrap toolchain that we should default to the latest available point release at the time we make the switch, not the initial major release, so as to avoid bugs that were fixed in the point releases. This CL updates the default search locations and the release notes. Users who run make.bash and depend on finding $HOME/sdk/go1.17 may need to run go install golang.org/dl/go1.17.13@latest go1.17.13 download to provide a Go 1.17.13 toolchain to their builds. Change-Id: I3a2511f088cf852470a7216a5a41ae775fb561b6 Reviewed-on: https://go-review.googlesource.com/c/go/+/439419 Reviewed-by: Ian Lance Taylor <iant@golang.org> Run-TryBot: Russ Cox <rsc@golang.org> Reviewed-by: Ian Lance Taylor <iant@google.com> TryBot-Result: Gopher Robot <gobot@golang.org>
Diffstat (limited to 'src/cmd/dist')
-rw-r--r--src/cmd/dist/notgo117.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cmd/dist/notgo117.go b/src/cmd/dist/notgo117.go
index eb1c949b00..8d551df24b 100644
--- a/src/cmd/dist/notgo117.go
+++ b/src/cmd/dist/notgo117.go
@@ -8,7 +8,7 @@
//
// % GOROOT_BOOTSTRAP=$HOME/sdk/go1.16 ./make.bash
// Building Go cmd/dist using /Users/rsc/sdk/go1.16. (go1.16 darwin/amd64)
// found packages main (build.go) and building_Go_requires_Go_1_17_or_later (notgo117.go) in /Users/rsc/go/src/cmd/dist
// %
//
// which is the best we can do under the circumstances.
@@ -19,4 +19,4 @@
//go:build !go1.17
// +build !go1.17
-package building_Go_requires_Go_1_17_or_later
+package building_Go_requires_Go_1_17_13_or_later
@@ -8,7 +8,7 @@
// % GOROOT_BOOTSTRAP=$HOME/sdk/go1.16 ./make.bash
// Building Go cmd/dist using /Users/rsc/sdk/go1.16. (go1.16 darwin/amd64)
-// found packages main (build.go) and building_Go_requires_Go_1_17_or_later (notgo117.go) in /Users/rsc/go/src/cmd/dist
+// found packages main (build.go) and building_Go_requires_Go_1_17_13_or_later (notgo117.go) in /Users/rsc/go/src/cmd/dist
// %
//